import { Component } from '@angular/core';
import { NavController, NavParams, ActionSheetController } from 'ionic-angular';
import { Camera } from 'ionic-native';
import { Product } from '../../models/product'
import { DataProvider } from '../../providers/data-provider'

@Component({
    selector: 'page-product-details',
    providers: [DataProvider],
    templateUrl: 'product-details.html'
})
export class ProductDetailsPage {

    product = {
        name: "",
        type: 0,
        salePrice: 0,
        ean13: "",
        reference: "",
        costPrice: 0,
        quantity: 0,
        salesCount: 0,
        image: null,
        active: true
    }

    constructor(
        public navCtrl: NavController,
        public params: NavParams,
        public data: DataProvider,
        public actionSheetCtrl: ActionSheetController
    ) { 
        this.initialize();
    }

    /**
     *
     */
    private initialize() {
        if (!(this.params.data instanceof Array)) {
            this.product = this.params.data;
        }
    }

    /**
     *
     */
    private isValidForm() {
        if (!this.product.name) {
            return false;
        }

        return true;
    }

    /**
     *
     */
    showPhotoOptions() {
        this.actionSheetCtrl.create({
            title: "Tomar una foto",
            buttons: [
                {
                    text: "Desde la cámara",
                    icon: "camera",
                    handler: () => {
                        this.takePicture(Camera.PictureSourceType.CAMERA);
                    }
                },
                {
                    text: "Desde la galería",
                    icon: "images",
                    handler: () => {
                        this.takePicture(Camera.PictureSourceType.SAVEDPHOTOALBUM);
                    }
                },
                {
                    text: "Cancelar",
                    role: "cancel"
                }
            ]
        }).present();
    }

    /**
     *
     */
    takePicture(sourceType: number) {
        Camera.getPicture({
            sourceType: sourceType,
            destinationType: Camera.DestinationType.DATA_URL,
            correctOrientation: true,
            saveToPhotoAlbum: false,
            targetHeight: 300,
            targetWidth: 300
        }).then(i => {
            this.product.image = i; 
        }).catch(e => {
            console.log(e);                    
        });
    }

    /**
     *
     */
    save(): void {
        if (!this.isValidForm()) {
            return;
        }

        this.data.save('product', this.product).then(result => {
            if (this.params.data instanceof Array) {
                this.params.data.push(result.products[0]);
            } 
            
            this.navCtrl.pop(this);
        }).catch(e => {
            console.log(e);
        });
    }
}
